@@ -2,21 +2,21 @@
 from dddd_utils.basespider import BaseSpider
 from dddd_utils.basespider_selenium import SeleniumBaseSpider
 from dddd_utils.retry import retry
-from dddd_utils.ftp import FtpDownload
+from dddd_utils.ftp import FtpTool
 from dddd_utils.mysql import StoreMysqlPool
-from dddd_utils.ffdm import get_ffdm_api
 from dddd_utils.logger import get_logger
 from dddd_utils.mail import UtilMail
 from dddd_utils.apollo import ApolloClient
+from yagmail import inline
 
 __all__ = [
     'BaseSpider',  # 爬虫基类
     'SeleniumBaseSpider',  # 浏览器爬虫基类
     'retry',  # 重试装饰器
-    'FtpDownload',  # ftp工具类
+    'FtpTool',  # ftp工具类
     'StoreMysqlPool',  # mysql
-    'get_ffdm_api',  # 验证码
     'get_logger',  # logger
     'UtilMail',  # 邮件工具类
+    'inline',  # 邮件 插入图片
     'ApolloClient'  # apollo 配置中心 python客户端
 ]
