@@ -9,12 +9,12 @@ __all__ = [
 ]
 
 
-def get_logger(name=None, log_path="", log_level="INFO", log_format='%(levelname)s - %(asctime)s - process: %(process)d - %(filename)s - %(name)s - %(lineno)d - %(module)s - %(message)s', log_enabled=True, log_to_console=True, log_to_file=True):
+def get_logger(name=None, log_path="", log_level="INFO", log_format='%(asctime)s - %(levelname)s - %(process)d - %(filename)s - %(name)s - %(lineno)d - %(module)s - %(message)s', log_enabled=True, log_to_console=True, log_to_file=True):
     """"""
     if not name: name = __name__
 
     logger = logging.getLogger(name)
-
+    logger.handlers.clear()
     log_level = getattr(logging, log_level) if isinstance(log_level, str) else log_level
     logger.setLevel(log_level)
 
